Contributing to dPayGo
====================

We welcome your contributions to our project.

Repository
----------

The repository of dPayGo is currently located at:

    https://github.com/dpays/dpaygo

Flow
----

This project makes heavy use of `git flow <http://nvie.com/posts/a-successful-git-branching-model/>`_.
If you are not familiar with it, then the most important thing for your
to understand is that:

    pull requests need to be made against the develop branch

How to Contribute
-----------------

0. Familiarize yourself with `contributing on github <https://guides.github.com/activities/contributing-to-open-source/>`
1. Fork or branch from the master.
2. Create commits following the commit style
3. Start a pull request to the master branch
4. Wait for a @holger80 or another member to review

Issues
------

Feel free to submit issues and enhancement requests.

Contributing
------------

Please refer to each project's style guidelines and guidelines for
submitting patches and additions. In general, we follow the
"fork-and-pull" Git workflow.

1. **Fork** the repo on GitHub
2. **Clone** the project to your own machine
3. **Commit** changes to your own branch
4. **Push** your work back up to your fork
5. Submit a **Pull request** so that we can review your changes

NOTE: Be sure to merge the latest from "upstream" before making a pull
request!

Copyright and Licensing
-----------------------

This library is open sources under the MIT license. We require your to
release your code under that license as well.
